use std::fs;
use std::io;
use std::path::{Path, PathBuf};
use std::process::Command;
use std::env;

fn process_compressed_files(path: &Path) -> io::Result<()> {
    if path.is_dir() {
        println!("Path: {}", path.display());
        for entry in fs::read_dir(path)? {
            let entry_path = fs::canonicalize(entry?.path())?;
            process_compressed_files(&entry_path)?;
        }
    } else {
        if path.extension().map_or(false, |ext|
            ext == "rar" || ext == "zip",
        ) {
            println!("UNAR: {}", path.display());
            let output = Command::new("unar")
                .current_dir(path)
                .arg(path)
                .output();

            match output {
                Ok(result) => {
                    if !result.status.success() {
                        eprintln!("Error processing compressed file {:?}: {}", path, String::from_utf8_lossy(&result.stderr));
                    }
                }
                Err(e) => {
                    eprintln!("Failed to execute unar for {:?}: {}", path, e);
                }
            }
        }
    }

    Ok(())
}

fn main() -> io::Result<()> {
    let args: Vec<String> = env::args().collect();

    let start_path = if args.len() > 1 {
        PathBuf::from(args[1].clone())
    } else {
        PathBuf::from(".")
    };
    process_compressed_files(&start_path)?;

    Ok(())
}
